Stan Math Library: stan/math/prim/mat/fun/initialize.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
initialize.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <boost/type_traits/is_arithmetic.hpp>`
`#include <boost/utility/enable_if.hpp>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
void | stan::math::initialize (T &x, const T &v)
template<typename T , typename V >
boost::enable_if_c< boost::is_arithmetic< V >::value, void >::type | stan::math::initialize (T &x, V v)
template<typename T , int R, int C, typename V >
void | stan::math::initialize (Eigen::Matrix< T, R, C > &x, const V &v)
template<typename T , typename V >
void | stan::math::initialize (std::vector< T > &x, const V &v)

[ Stan Home Page ] © 2011–2016, Stan Development Team.